@@ -429,35 +429,52 @@ function(net.layers, new.layer){
 }
 
 
-callrelax <- function (net) {
-	if (requireNamespace("optmatch", quietly = TRUE)) {
-		startn <- net$startn
-	    	endn <- net$endn
-	    	ucap <- net$ucap
-	    	b <- net$b
-	    	cost <- net$cost
-	    	stopifnot(length(startn) == length(endn))
-	    	stopifnot(length(startn) == length(ucap))
-	    	stopifnot(length(startn) == length(cost))
-	    	stopifnot(min(c(startn, endn)) >= 1)
-	    	stopifnot(max(c(startn, endn)) <= length(b))
-	    	stopifnot(all(startn != endn))
-	
-	    	nnodes <- length(b)
-	    my.expr <- parse(text = '.Fortran("relaxalg", nnodes, as.integer(length(startn)), 
-	    	    as.integer(startn), as.integer(endn), as.integer(cost), 
-	    	    as.integer(ucap), as.integer(b), x1 = integer(length(startn)), 
-	    	    crash1 = as.integer(0), large1 = as.integer(.Machine$integer.max/4), 
-	    	    feasible1 = integer(1), NAOK = FALSE, DUP = TRUE, PACKAGE = "optmatch")')
-		fop <- eval(my.expr)	
-	   	x <- fop$x1
-	    	feasible <- fop$feasible1
-	    	crash <- fop$crash1
-		return(list(crash = crash, feasible = feasible, x = x))
-	} else {
-			  warning('Package optmatch (>= 0.9-1) not loaded, so rcbalance could not perform the usual match; returning NULL.')
-		return(list(crash = 0, feasible = 1, x = rep(0, length(cost)), no.optmatch = TRUE))		
+callrelax <- function (net, solver = 'rlemon') {
+  startn <- net$startn
+  endn <- net$endn
+  ucap <- net$ucap
+  b <- net$b
+  cost <- net$cost
+  stopifnot(length(startn) == length(endn))
+  stopifnot(length(startn) == length(ucap))
+  stopifnot(length(startn) == length(cost))
+  stopifnot(min(c(startn, endn)) >= 1)
+  stopifnot(max(c(startn, endn)) <= length(b))
+  stopifnot(all(startn != endn))
+  
+  nnodes <- length(b)
+  if(solver == 'rrelaxiv'){
+    if(requireNamespace('rrelaxiv', quietly = TRUE)) {
+      rout <- rrelaxiv::RELAX_IV(startnodes = as.integer(startn),
+                                 endnodes = as.integer(endn),
+                                 arccosts = as.integer(cost),
+                                 arccapacity = as.integer(ucap),
+                                 supply = as.integer(b))
+      return.obj <- list(crash = 0,
+                         feasible = !all(rout == 0),
+                         x = rout)
+      return(return.obj) 
+    } else {
+      solver = 'rlemon'
+      warning('Package rrelaxiv not available, using rlemon instead.')
     }
+  }
+  if(solver == 'rlemon'){    
+    lout <- rlemon::MinCostFlow(arcSources = as.integer(startn),
+                                arcTargets = as.integer(endn),
+                                arcCapacities = as.integer(ucap),
+                                arcCosts = as.integer(cost),
+                                nodeSupplies = as.integer(b),
+                                numNodes = max(c(startn, endn)),
+                                algorithm = 'CycleCancelling')
+    return.obj <- list(crash = 0,
+                       feasible = !all(lout[[1]] == 0),
+                       x = lout[[1]])
+    return(return.obj) 
+  }else{
+    stop(
+      'Argument to solver not recognized: please use one of rlemon and rrelaxiv')
+  }
 }
 
 penalty.update <-
